@@ -1,5 +1,5 @@
 package CPAN::Meta::Prereqs::Filter;
-$CPAN::Meta::Prereqs::Filter::VERSION = '0.002';
+$CPAN::Meta::Prereqs::Filter::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -23,17 +23,15 @@ sub _normalize_version {
 	if (isvstring($raw)) {
 		$raw = sprintf 'v%vd', $raw;
 	}
-	if ($raw =~ /v5\.[\d.]+/) {
+	if ($raw =~ / \A v5 (?> \. \d+)* \z /x) {
 		require version;
-		$raw = version->new($raw)->numify;
-		my $pattern = $raw >= 5.010 ? '%7.6f' : '%4.3f';
-		return sprintf $pattern, $raw;
+		return sprintf '%7.6f', version->new($raw)->numify;
 	}
 	elsif ($raw eq 'latest') {
 		require Module::CoreList;
 		return (reverse sort keys %Module::CoreList::version)[0];
 	}
-	return $raw >= 5.010 ? sprintf '%7.6f', $raw : $raw;
+	return sprintf '%7.6f', $raw;
 }
 
 sub filter_prereqs {
@@ -112,7 +110,7 @@ CPAN::Meta::Prereqs::Filter - Filtering various things out of CPAN::Meta::Prereq
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
